<?php

/*
Plugin Name: StatsLab Awards for OOTP Widget
Description: This widget allows you to display StatsLab Award Winners in WordPress
Version    : 1.0
Author     : Frank Esselink
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

defined( 'ABSPATH' ) or die( 'Boo!' );

class StatsLab_OOTP_Awards_Widget extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		// widget actual processes
		parent::__construct(
			'statslab_ootp_awards_widget',
			__('StatsLab Awards', 'statslab_ootp_awards_widget_domain'),
			array( 'description' => __( 'Widget to display StatsLab awards on your WordPress site', 'statslab_ootp_awards_widget_domain'), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		// outputs the content of the widget
		$title = apply_filters( 'widget_title', $instance['title'] );
		echo $args['before_widget'];
		if ( ! empty( $title ) )
		echo $args['before_title'] . $title . $args['after_title'];

		echo __($this->dispAwardWinner($instance), 'statslab_ootp_awards_widget_domain');

		echo $args['after_widget'];
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		// outputs the options form on admin
		if ( isset( $instance[ 'title' ] ) ) {$title = $instance[ 'title' ];} else {$title = __( 'New Title', 'statslab_ootp_awards_widget_domain');}
		if ( isset( $instance[ 'sl_path' ] ) ) {$sl_path = $instance[ 'sl_path' ];} else {$sl_path = __( '/home/account/domain.com/StatsLab', 'statslab_ootp_awards_widget_domain');}
		if ( isset( $instance[ 'sl_show' ] ) ) {$sl_show = $instance[ 'sl_show' ];} else {$sl_show = __( 'potm', 'statslab_ootp_awards_widget_domain');}
		if ( isset( $instance[ 'league_id' ] ) ) {$league_id = $instance[ 'league_id' ];} else {$league_id = __( 100, 'statslab_ootp_awards_widget_domain');}
		if ( isset( $instance[ 'subleague_id' ] ) ) {$subleague_id = $instance[ 'subleague_id' ];} else {$subleague_id = __( 0, 'statslab_ootp_awards_widget_domain');}

		echo "<p>";
		// Title this widget
		echo " <label for=\"" . $this->get_field_id( 'title' ) . "\">" . _e( 'Title:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'title' ) . "\" name=\"" . $this->get_field_name( 'title' ) . "\" type=\"text\" value=\"" . esc_attr( $title ). "\" />";

		// Define path to StatsLab
		echo " <label for=\"" . $this->get_field_id( 'sl_path' ) . "\">" . _e( 'StatsLab Path:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'sl_path' ) . "\" name=\"" . $this->get_field_name( 'sl_path' ) . "\" type=\"text\" value=\"" . $sl_path . "\" />";

		// Display Show Selector
		$showOptions = Array (
			'potw'=>'Player of the Week', 
			'botm'=>'Batter of the Month', 
			'potm'=>'Pitcher of the Month', 
			'rotm'=>'Rookie of the Month', 
		);
		echo " <label for=\"" . $this->get_field_id( 'sl_show' ) . "\">" . _e( 'Show:' ) . "</label>";
		echo " <select class=\"widefat\" id=\"" . $this->get_field_id( 'sl_show' ) . "\" name=\"" . $this->get_field_name( 'sl_show' ) . "\" type=\"text\" value=\"" . $sl_show . "\" title=\"" . $sl_show . "\">";
		foreach ($showOptions as $key => $val)
		{
			echo "  <option";
			echo selected( $instance['sl_show'], $key);
			echo " value='$key'>";
			echo "$val</option>";
		}
		echo " </select>";

		// League ID
		echo " <label for=\"" . $this->get_field_id( 'league_id' ) . "\">" . _e( 'League ID:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'league_id' ) . "\" name=\"" . $this->get_field_name( 'league_id' ) . "\" type=\"text\" value=\"" . esc_attr( $league_id ). "\" />";

		// Subleague ID
		echo " <label for=\"" . $this->get_field_id( 'subleague_id' ) . "\">" . _e( 'Subleague ID:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'subleague_id' ) . "\" name=\"" . $this->get_field_name( 'subleague_id' ) . "\" type=\"text\" value=\"" . max(0,esc_attr( $subleague_id )) . "\" />";

		echo "</p>";
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 */
	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
		$instance = array();
		$instance['title']        = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['sl_path']      = ( ! empty( $new_instance['sl_path'] ) ) ? strip_tags( $new_instance['sl_path'] ) : '';
		$instance['sl_show']      = $new_instance['sl_show'];
		$instance['league_id']    = ( ! empty( $new_instance['league_id'] ) ) ? strip_tags( $new_instance['league_id'] ) : '';
		$instance['subleague_id'] = ( ! empty( $new_instance['subleague_id'] ) ) ? strip_tags( $new_instance['subleague_id'] ) : '';
		return $instance;
	}
	
	private function dispAwardWinner( $instance) {
		$fpath=$instance['sl_path']."/config.txt";
		if (file_exists($fpath))
		{
			$f = fopen ($fpath, "r");
			$line = explode("|",fread($f,filesize($fpath)));
			$adminpath = trim($line[1]);
			fclose($f);
		}
		else {return "Unable to find StatsLab config file: $fpath";}

		$fpath=$adminpath."/dbopen.php";
		include($fpath);

		include_once($instance['sl_path']."/gen_functions.php");

		if ($db===null) {return "Unable to connect to database";}
	
		$text="";
		$league_id=$instance['league_id'];
		$subleague_id=$instance['subleague_id'];
		if ($subleague_id=="") {$subleague_id=0;}
		$show=$instance['sl_show'];
		switch ($show)
     		{
			case 'potw': $awID=0; break;
			case 'potm': $awID=1; break;
	     		case 'botm': $awID=2; break;
			case 'rotm': $awID=3; break;
     		}
	
		// Get Paths
		$query="SHOW TABLES LIKE 'ootp_sql_admin';";
		$result=mysql_query($query,$db);
		if (mysql_num_rows($result)) 
		{
			$query="SELECT setting,value FROM ootp_sql_admin WHERE module='admin' AND setting IN ('HTMLRoot','HTMLPath','ServerURL','StatsLabPath','priLgID')";
			$result=mysql_query($query,$db);
			if (mysql_num_rows($result)) 
			{
				while ($row=mysql_fetch_array($result))
				{
					$field=$row['setting'];
					$val=$row['value'];
					$val=stripslashes($val);
					switch ($field)
					{
					case 'HTMLRoot' : $htmlroot=$val; break;
					case 'HTMLPath' : $htmlpath=$val; break;
					case 'ServerURL': $serverURL=$val;break;
					case 'StatsLabPath': $StatsLabPath=$val;break;
					case 'priLgID'  : if ($lgid=="") {$lgid=$val;}break;
					}
				}
				$lgpath=$serverURL.$htmlpath;
				if (strtolower(substr($StatsLabPath,0,4))!="http") {$StatsLabPath=$serverURL.$StatsLabPath;}
			}
		}

		// Get team info
		$query="SELECT team_id,sub_league_id,name,nickname,abbr FROM teams WHERE league_id=$league_id AND allstar_team=0";
		$result=mysql_query($query,$db);
		if (mysql_num_rows($result)) 
		{
			while($row=mysql_fetch_array($result))
			{
				$tid=$row['team_id'];
				$teams[$tid]['city']=$row['name'];
				$teams[$tid]['nickname']=$row['nickname'];
				$teams[$tid]['name']=$row['name']." ".$row['nickname'];
				$teams[$tid]['abbr']=$row['abbr'];

				$slid=$row['sub_league_id'];
				$subleagues[$slid]['teams']=$subleagues[$slid]['teams'].",".$tid;
			}
			foreach ($subleagues as $slid => $val) {$subleagues[$slid]['teams']=trim($subleagues[$slid]['teams'],",");}
		}

		// Get Award Winner Info
		$query="SELECT p.player_id,first_name,last_name,p.position,pa.team_id,pa.year as awYear,pa.month as awMonth,pa.day as awDay FROM players as p,players_awards as pa WHERE p.player_id=pa.player_id AND pa.league_id=$league_id AND pa.sub_league_id=$subleague_id AND award_id=$awID ORDER BY pa.year DESC,pa.month DESC,pa.day DESC LIMIT 1";
		if ($_GET['showq']==1) {$text.="$query<br/>\n";}
     		$result=mysql_query($query,$db);
		if (mysql_num_rows($result))
     		{
			$row=mysql_fetch_array($result);
     			$pid=$row['player_id'];
			$tid=$row['team_id'];
     			$tabbr=$teams[$tid]['abbr'];
			$awYear =$row['awYear'];
     			$awMonth=$row['awMonth'];
			$awDay  =$row['awDay'];
     			$name=$row['first_name']." ".$row['last_name'];
			$pos=$row['position'];

			if (($pos>1)||($show=='botm'))
     			{
				$query="SELECT player_id,ps.team_id,if(SUM(ab)=0,0,SUM(h)/SUM(ab)) as avg,SUM(h) as h,SUM(hr) as hr,SUM(ab) as ab,SUM(rbi) as rbi,SUM(sb) as sb FROM players_game_batting as ps,games as g WHERE ps.player_id=$pid AND ps.game_id=g.game_id AND game_type=0";
				if ($show=='potw')
     				{
					$query.=" AND DATEDIFF('$awYear-$awMonth-$awDay',g.date)<9 AND DATEDIFF('$awYear-$awMonth-$awDay',g.date)>1";
     				}
				else
     				{
					$query.=" AND g.date LIKE '".(($awMonth==1)?($awYear-1):$awYear)."-".str_pad((($awMonth==1)?12:($awMonth-1)),2,0,STR_PAD_LEFT)."-%'";
     				}
				$query.=" GROUP BY player_id";
     				if ($_GET['showq']==1) {$text.="$query<br/>\n";}
				$result=mysql_query($query,$db);
     				$row=mysql_fetch_array($result);

				$text.="<div style='text-align:center;'>";
     				$text.="<img src='".get_player_pic($lgpath,$pid)."'><br/>";
				$text.="<a href='$StatsLabPath/player.php?player_id=$pid'>$name</a> - <a href='$lgpath/teams/team_$tid.html'>$tabbr</a><br/>".stat_format('avg',$row['avg']).", ".$row['hr']." HR, ".$row['rbi']." RBI";
     				$text.="</div>\n";
			}
     			else
			{
     				$query="SELECT player_id,ps.team_id,if(SUM(ip)+SUM(ipf)/3=0,0,9*SUM(er)/(SUM(ip)+SUM(ipf)/3)) as era,SUM(w) as w,SUM(l) as l,SUM(k) as k,SUM(s) as s FROM players_game_pitching_stats as ps,games as g WHERE ps.player_id=$pid AND ps.game_id=g.game_id AND game_type=0";
				if ($show=='potw')
     				{
					$query.=" AND DATEDIFF('$awYear-$awMonth-$awDay',g.date)<9 AND DATEDIFF('$awYear-$awMonth-$awDay',g.date)>1";
     				}
				else
     				{
					$query.=" AND g.date LIKE '".(($awMonth==1)?($awYear-1):$awYear)."-".str_pad((($awMonth==1)?12:($awMonth-1)),2,0,STR_PAD_LEFT)."-%'";
     				}
				$query.=" GROUP BY player_id";
     				if ($_GET['showq']==1) {$text.="$query<br/>\n";}
				$result=mysql_query($query,$db);
     				$row=mysql_fetch_array($result);

	     
				$text.="<div style='text-align:center;'>";
				$text.="<img src='".get_player_pic($lgpath,$pid)."'><br/>";
     				$text.="<a href='$StatsLabPath/player.php?player_id=$pid'>$name</a> - <a href='$lgpath/teams/team_$tid.html'>$tabbr</a><br/>".$row['w']."-".$row['l'].", ";
				if ($row['s']>0) {$text.=$row['s']." SV, ";}
     				$text.=stat_format('era',$row['era'])." ERA, ".$row['k']." K";
				$text.="</div>\n";
     			}
		}

		return $text;
		mysql_close($db);
	}	
}

// Register and load the widget
function statslab_ootp_load_awards_widget() {
    register_widget( 'StatsLab_OOTP_Awards_Widget' );
}

add_action( 'widgets_init', 'statslab_ootp_load_awards_widget' );




####################################################
# get_player_pic
#  gets the url of the player picture
#
# Parameters:
#  lgpath - the path to the league's html
#  pid    - the player ID
####################################################
function get_player_pic($lgpath,$pid)
{
      	$imgpath=$lgpath."/images/person_pictures/player_".$pid.".png";            ## Check for photo by player ID
	$ch = curl_init($imgpath);
      	curl_setopt($ch, CURLOPT_NOBODY, true);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
      	curl_setopt($ch, CURLOPT_FILETIME, true); 
	curl_exec($ch);
      	$retcode = curl_getinfo($ch, CURLINFO_HTTP_CODE); // $retcode > 400 -> not found, $retcode = 200, found.
	if ($retcode==200) {return $imgpath;}
      	else
	{
      		$imgpath=$lgpath."/images/person_pictures/".str_replace(" ","_",$name).".png";   ## Check for capitalized name PNG
		$ch = curl_init($imgpath);
      		curl_setopt($ch, CURLOPT_NOBODY, true);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
      		curl_setopt($ch, CURLOPT_FILETIME, true); 
		curl_exec($ch);
      		$retcode = curl_getinfo($ch, CURLINFO_HTTP_CODE); // $retcode > 400 -> not found, $retcode = 200, found.
		if ($retcode==200) {return $imgpath;}
		else
		{
      			$imgpath=$lgpath."/images/person_pictures/".str_replace(" ","_",strtolower($name)).".png";   ## Check for lowercase name PNG
			$ch = curl_init($imgpath);
      			curl_setopt($ch, CURLOPT_NOBODY, true);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
      			curl_setopt($ch, CURLOPT_FILETIME, true); 
			curl_exec($ch);
      			$retcode = curl_getinfo($ch, CURLINFO_HTTP_CODE); // $retcode > 400 -> not found, $retcode = 200, found.
			if ($retcode==200) {return $imgpath;}
			else
			{
      				$imgpath=$lgpath."/images/person_pictures/".str_replace(" ","_",$name).".jpg";   ## Check for capitalized name JPG
				$ch = curl_init($imgpath);
      				curl_setopt($ch, CURLOPT_NOBODY, true);
				curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
      				curl_setopt($ch, CURLOPT_FILETIME, true); 
				curl_exec($ch);
      				$retcode = curl_getinfo($ch, CURLINFO_HTTP_CODE); // $retcode > 400 -> not found, $retcode = 200, found.
				if ($retcode==200) {return $imgpath;}
      				else
				{
      					$imgpath=$lgpath."/images/person_pictures/".str_replace(" ","_",strtolower($name)).".jpg";   ## Check for lowercase name JPG
					$ch = curl_init($imgpath);
      					curl_setopt($ch, CURLOPT_NOBODY, true);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
      					curl_setopt($ch, CURLOPT_FILETIME, true); 
					curl_exec($ch);
      					$retcode = curl_getinfo($ch, CURLINFO_HTTP_CODE); // $retcode > 400 -> not found, $retcode = 200, found.
					if ($retcode==200) {return $imgpath;}
					else
					{
						$imgpath=$lgpath."/images/person_pictures/".str_replace(" ","_",$name).".bmp";   ## Check for capitalized name BMP
						$ch = curl_init($imgpath);
      						curl_setopt($ch, CURLOPT_NOBODY, true);
						curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
      						curl_setopt($ch, CURLOPT_FILETIME, true); 
						curl_exec($ch);
      						$retcode = curl_getinfo($ch, CURLINFO_HTTP_CODE); // $retcode > 400 -> not found, $retcode = 200, found.
						if ($retcode==200) {return $imgpath;}
      						else
						{
      							$imgpath=$lgpath."/images/person_pictures/".str_replace(" ","_",strtolower($name)).".bmp";   ## Check for lowercase name bmp
							$ch = curl_init($imgpath);
      							curl_setopt($ch, CURLOPT_NOBODY, true);
							curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
      							curl_setopt($ch, CURLOPT_FILETIME, true); 
							curl_exec($ch);
      							$retcode = curl_getinfo($ch, CURLINFO_HTTP_CODE); // $retcode > 400 -> not found, $retcode = 200, found.
							if ($retcode==200) {return $imgpath;}
      							else
							{
      								return "$lgpath/images/person_pictures/default_player_photo.png";   ## Show default
							}
      						}
					}
      				}
			}
      		}
	}
}
?>
