<?php

/*
Plugin Name: StatsLab for OOTP Standings Widget
Description: This widget allows you to display division standings from StatsLab in WordPress
Version    : 1.0
Author     : Frank Esselink
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

defined( 'ABSPATH' ) or die( 'Boo!' );

class StatsLab_OOTP_Standings_Widget extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		// widget actual processes
		parent::__construct(
			'statslab_ootp_standings_widget',
			__('StatsLab Standings', 'statslab_ootp_standings_widget_domain'),
			array( 'description' => __( 'Widget to display division standings from StatsLab on your WordPress site', 'statslab_ootp_standings_widget_domain'), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		// outputs the content of the widget
		$title = apply_filters( 'widget_title', $instance['title'] );
		echo $args['before_widget'];
		if ( ! empty( $title ) )
		echo $args['before_title'] . $title . $args['after_title'];

		echo __($this->dispWidget($instance), 'statslab_ootp_standings_widget_domain');

		echo $args['after_widget'];
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		// outputs the options form on admin
		if ( isset( $instance[ 'title' ] ) ) {$title = $instance[ 'title' ];} else {$title = __( 'New Title', 'statslab_ootp_standings_widget_domain');}
		if ( isset( $instance[ 'sl_path' ] ) ) {$sl_path = $instance[ 'sl_path' ];} else {$sl_path = __( 'http://www.domain.com/StatsLab', 'statslab_ootp_standings_widget_domain');}
		if ( isset( $instance[ 'league_id' ] ) ) {$league_id = $instance[ 'league_id' ];} else {$league_id = __( 100, 'statslab_ootp_standings_widget_domain');}
		if ( isset( $instance[ 'subleague_id' ] ) ) {$subleague_id = $instance[ 'subleague_id' ];} else {$subleague_id = __( 0, 'statslab_ootp_standings_widget_domain');}
		if ( isset( $instance[ 'division_id' ] ) ) {$division_id = $instance[ 'division_id' ];} else {$division_id = __( 0, 'statslab_ootp_standings_widget_domain');}

		echo "<p>";
		// Title this widget
		echo " <label for=\"" . $this->get_field_id( 'title' ) . "\">" . _e( 'Title:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'title' ) . "\" name=\"" . $this->get_field_name( 'title' ) . "\" type=\"text\" value=\"" . esc_attr( $title ). "\" />";

		// Define path to StatsLab
		echo " <label for=\"" . $this->get_field_id( 'sl_path' ) . "\">" . _e( 'StatsLab Path:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'sl_path' ) . "\" name=\"" . $this->get_field_name( 'sl_path' ) . "\" type=\"text\" value=\"" . $sl_path . "\" />";

		// League ID
		echo " <label for=\"" . $this->get_field_id( 'league_id' ) . "\">" . _e( 'League ID:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'league_id' ) . "\" name=\"" . $this->get_field_name( 'league_id' ) . "\" type=\"text\" value=\"" . esc_attr( $league_id ). "\" />";

		// Subleague ID
		echo " <label for=\"" . $this->get_field_id( 'subleague_id' ) . "\">" . _e( 'Subleague ID:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'subleague_id' ) . "\" name=\"" . $this->get_field_name( 'subleague_id' ) . "\" type=\"text\" value=\"" . max(0,esc_attr( $subleague_id )) . "\" />";

		// Division ID
		echo " <label for=\"" . $this->get_field_id( 'division_id' ) . "\">" . _e( 'Division ID:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'division_id' ) . "\" name=\"" . $this->get_field_name( 'division_id' ) . "\" type=\"text\" value=\"" . max(0,esc_attr( $division_id )) . "\" />";

		echo "</p>";
	}

	private function dispWidget( $instance) {
		$fpath=$instance['sl_path']."/config.txt";
		if (file_exists($fpath))
		{
			$f = fopen ($fpath, "r");
			$line = explode("|",fread($f,filesize($fpath)));
			$adminpath = trim($line[1]);
			fclose($f);
		}
		else {return "Unable to find StatsLab config file: $fpath";}

		$fpath=$adminpath."/dbopen.php";
		include($fpath);

		if ($db===null) {return "Unable to connect to database";}

		$text="";
		$league_id=$instance['league_id'];
		$subleague_id=$instance['subleague_id'];
		$division_id=$instance['division_id'];

		// Get Paths
		$query="SHOW TABLES LIKE 'ootp_sql_admin';";
		$result=mysql_query($query,$db);
		if (mysql_num_rows($result)) 
		{
			$query="SELECT setting,value FROM ootp_sql_admin WHERE module='admin' AND setting IN ('HTMLRoot','HTMLPath','ServerURL','StatsLabPath','priLgID')";
			$result=mysql_query($query,$db);
			if (mysql_num_rows($result)) 
			{
				while ($row=mysql_fetch_array($result))
				{
					$field=$row['setting'];
					$val=$row['value'];
					$val=stripslashes($val);
					switch ($field)
					{
					case 'HTMLRoot' : $htmlroot=$val; break;
					case 'HTMLPath' : $htmlpath=$val; break;
					case 'ServerURL': $serverURL=$val;break;
					case 'StatsLabPath': $StatsLabPath=$val;break;
					case 'priLgID'  : if ($lgid=="") {$lgid=$val;}break;
					}
				}
				$lgpath=$serverURL.$htmlpath;
				if (strtolower(substr($StatsLabPath,0,4))!="http") {$StatsLabPath=$serverURL.$StatsLabPath;}
			}
		}

		// Get league, division, and team info
		$query="SELECT sub_league_id,name,abbr FROM sub_leagues WHERE league_id=$league_id AND sub_league_id=$subleague_id";
		$result=mysql_query($query,$db);
		if (mysql_num_rows($result)) 
		{
			$row=mysql_fetch_array($result);
			$slid=$row['sub_league_id'];
			$subleagues[$slid]['name']=$row['name'];
			$subleagues[$slid]['abbr']=$row['abbr'];
		}
		$query="SELECT sub_league_id,division_id,name FROM divisions WHERE league_id=$league_id AND sub_league_id=$subleague_id AND division_id=$division_id";
		$result=mysql_query($query,$db);
		if (mysql_num_rows($result)) 
		{
			$row=mysql_fetch_array($result);
			$slid=$row['sub_league_id'];
			$divID=$row['division_id'];
			$divisions[$divID]['name']=$row['name'];
		}
		$query="SELECT team_id,name,nickname,abbr FROM teams WHERE league_id=$league_id AND allstar_team=0";
		$result=mysql_query($query,$db);
		if (mysql_num_rows($result)) 
		{
			while($row=mysql_fetch_array($result))
			{
				$tid=$row['team_id'];
				$teams[$tid]['city']=$row['name'];
				$teams[$tid]['nickname']=$row['nickname'];
				$teams[$tid]['name']=$row['name']." ".$row['nickname'];
				$teams[$tid]['abbr']=$row['abbr'];
			}
		}

		// Generate results
		$query="SELECT t.team_id,w,l,gb,sub_league_id,division_id FROM team_record as t,team_relations as tr WHERE t.team_id=tr.team_id AND tr.league_id=$league_id";
		$query.=" AND sub_league_id=$subleague_id AND division_id=$division_id";
	   	$query.=" ORDER BY sub_league_id,division_id,gb;";
		if ($_GET['showq']==1) {echo "$query<br/>\n";}
	   	$result=mysql_query($query,$db);
		$prevDiv="";
	   	while ($row=mysql_fetch_array($result))
		{
			$tid=$row['team_id'];
			$wins=$row['w'];
			$loss=$row['l'];
			$gb=$row['gb'];
			if ($gb==0) {$gb="-";}
			$slid=$row['sub_league_id'];
			$divID=$row['division_id'];
		
			if ($prevDiv!=$divID) {$cnt=0;}
			$cls='wdg'.($cnt%2+1);
			$divisions[$divID]['standings']=$divisions[$divID]['standings']." <tr class='$cls'><td class='".$cls."_l'><a href='$lgpath/teams/team_$tid.html'>".$teams[$tid]['city']."</a></td><td>$wins</td><td>$loss</td><td>$gb</td></tr>\n";
			if (($gb=="-")&&(!isset($divisions[$divID]['leader']))) {$divisions[$divID]['leader']=$divisions[$divID]['leader']."<li class='wdgLI'>".$subleagues[$slid]['abbr']." ".$divisions[$divID]['name'].": <a href='$lgpath/teams/team_$tid.html'>".$teams[$tid]['city']."</a></li>\n";}
			$prevDiv=$divID;
			$cnt++;
	  	}
		$text.= "<table class='wdgT'>\n";
	   	$text.= " <thead><tr class='wdgH'><td class='wdgH_l'>".$subleagues[$subleague_id]['abbr']." ".$divisions[$division_id]['name']."</td><td>W</td><td>L</td><td>GB</td></tr></thead>\n";
		$text.= $divisions[$division_id]['standings'];
		$text.= "</table>";

		return $text;
		mysql_close($db);
	}	
}

// Register and load the widget
function statslab_ootp_load_standings_widget() {
    register_widget( 'StatsLab_OOTP_Standings_Widget' );
}

add_action( 'widgets_init', 'statslab_ootp_load_standings_widget' );
?>
