<?php

/*
Plugin Name: StatsLab Stat Leaders for OOTP Widget
Description: This widget allows you to display StatsLab leaderboards in WordPress
Version    : 1.0
Author     : Frank Esselink
License:     GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

defined( 'ABSPATH' ) or die( 'Boo!' );

class StatsLab_OOTP_Widget extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		// widget actual processes
		parent::__construct(
			'statslab_ootp_widget',
			__('StatsLab Leaders', 'statslab_ootp_widget_domain'),
			array( 'description' => __( 'Widget to display StatsLab data on your WordPress site', 'statslab_ootp_widget_domain'), )
		);
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		// outputs the content of the widget
		$title = apply_filters( 'widget_title', $instance['title'] );
		echo $args['before_widget'];
		if ( ! empty( $title ) )
		echo $args['before_title'] . $title . $args['after_title'];

		echo __($this->dispStatsLeaders($instance), 'statslab_ootp_widget_domain');

		echo $args['after_widget'];
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		// outputs the options form on admin
		if ( isset( $instance[ 'title' ] ) ) {$title = $instance[ 'title' ];} else {$title = __( 'New Title', 'statslab_ootp_widget_domain');}
		if ( isset( $instance[ 'sl_path' ] ) ) {$sl_path = $instance[ 'sl_path' ];} else {$sl_path = __( '/home/account/domain.com/StatsLab', 'statslab_ootp_widget_domain');}
		if ( isset( $instance[ 'league_id' ] ) ) {$league_id = $instance[ 'league_id' ];} else {$league_id = __( 100, 'statslab_ootp_widget_domain');}
		if ( isset( $instance[ 'subleague_id' ] ) ) {$subleague_id = $instance[ 'subleague_id' ];} else {$subleague_id = __( 0, 'statslab_ootp_widget_domain');}
		if ( isset( $instance[ 'division_id' ] ) ) {$division_id = $instance[ 'division_id' ];} else {$division_id = __( 0, 'statslab_ootp_widget_domain');}
		if ( isset( $instance[ 'sl_topx' ] ) ) {$sl_topx = $instance[ 'sl_topx' ];} else {$sl_topx = __( 5, 'statslab_ootp_widget_domain');}
		if ( isset( $instance[ 'sl_stat' ] ) ) {$sl_stat = $instance[ 'sl_stat' ];} else {$sl_stat = __( 'avg', 'statslab_ootp_widget_domain');}
		if ( isset( $instance[ 'sl_lastx' ] ) ) {$sl_lastx = $instance[ 'sl_lastx' ];} else {$sl_lastx = __( 5, 'statslab_ootp_widget_domain');}
		if ( isset( $instance[ 'sl_nextx' ] ) ) {$sl_nextx = $instance[ 'sl_nextx' ];} else {$sl_nextx = __( 5, 'statslab_ootp_widget_domain');}

		echo "<p>";
		// Title this widget
		echo " <label for=\"" . $this->get_field_id( 'title' ) . "\">" . _e( 'Title:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'title' ) . "\" name=\"" . $this->get_field_name( 'title' ) . "\" type=\"text\" value=\"" . esc_attr( $title ). "\" />";

		// Define path to StatsLab
		echo " <label for=\"" . $this->get_field_id( 'sl_path' ) . "\">" . _e( 'StatsLab Path:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'sl_path' ) . "\" name=\"" . $this->get_field_name( 'sl_path' ) . "\" type=\"text\" value=\"" . $sl_path . "\" />";

		// League ID
		echo " <label for=\"" . $this->get_field_id( 'league_id' ) . "\">" . _e( 'League ID:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'league_id' ) . "\" name=\"" . $this->get_field_name( 'league_id' ) . "\" type=\"text\" value=\"" . esc_attr( $league_id ). "\" />";

		// Subleague ID
		echo " <label for=\"" . $this->get_field_id( 'subleague_id' ) . "\">" . _e( 'Subleague ID:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'subleague_id' ) . "\" name=\"" . $this->get_field_name( 'subleague_id' ) . "\" type=\"text\" value=\"" . max(-1,esc_attr( $subleague_id )) . "\" />";

		/*
		// Division ID
		echo " <label for=\"" . $this->get_field_id( 'division_id' ) . "\">" . _e( 'Division ID:' ) . "</label>";
		echo " <input class=\"widefat\" id=\"" . $this->get_field_id( 'division_id' ) . "\" name=\"" . $this->get_field_name( 'division_id' ) . "\" type=\"text\" value=\"" . max(0,esc_attr( $division_id )) . "\" />";
		 */

		// TopX
		$numberToDisplay = Array (1, 3, 5, 10, 25);
		echo " <label for=\"" . $this->get_field_id( 'sl_topx' ) . "\">" . _e( 'Display Top X Stats Leaders:' ) . "</label>";
		echo " <select class=\"widefat\" id=\"" . $this->get_field_id( 'sl_topx' ) . "\" name=\"" . $this->get_field_name( 'sl_topx' ) . "\" type=\"text\" value=\"" . $sl_topx . "\">";
		foreach ($numberToDisplay as $key => $val)
		{
			echo "  <option";
			if ($val == $instance['sl_topx']) {echo " selected='selected'";}
			echo ">$val</option>";
		}
		echo " </select>";

		// Display Stat Selector
		$statArray=array('batters'=>'Batting','ab'=>'AB','h'=>'H','d'=>'2B','t'=>'3B','hr'=>'HR','rbi'=>'RBI','r'=>'R','sb'=>'SB','cs'=>'CS','bb'=>'BB','k'=>'K','sf'=>'SF','sh'=>'SH','ibb'=>'IBB','hp'=>'HBP','gdp'=>'GIDP','pa'=>'PA','outs'=>'Outs','ebh'=>'EBH','tb'=>'TB','tob'=>'TOB','tto'=>'TTO','pitches_seen'=>'Pitches Seen','pipa'=>'PS/PA','abhr'=>'AB/HR','pahr'=>'PA/HR','bbk'=>'BB/K','avg'=>'AVG','obp'=>'OBP','slg'=>'SLG','ops'=>'OPS','iso'=>'ISO','bbabip'=>'BABIP','wOBA'=>'wOBA','war'=>"WAR",'pwrspd'=>'PwrSpd','bsba'=>'SBA','sbPct'=>'SB%','rc'=>'RC','rc27'=>'RC/27','pitchers'=>'Pitching','w'=>'W','l'=>'L','s'=>'SV','ip'=>'IP','g'=>'G','gs'=>'GS','gf'=>'GF','cg'=>'CG','sho'=>'SHO','qs'=>'QS','pk'=>'K','pbb'=>'BB','ha'=>'HA','hra'=>'HR','pr'=>'R','er'=>'ER','hld'=>'HLD','svo'=>'SVO','bs'=>'BS','da'=>'2BA','ta'=>'3BA','bk'=>'BK','wp'=>'WP','hp'=>'HP','bf'=>'BF','gb'=>'GB','fb'=>'FB','ptto'=>'TTO','pi'=>'Pitches Thrown','era'=>'ERA','whip'=>'WHIP','pwar'=>'WAR','kper9'=>'K/9IP','bbper9'=>'BB/9IP','hper9'=>'H/9IP','rper9'=>'R/9IP','hrper9'=>'HR/9IP','kperbb'=>'K/BB','gbPct'=>'GB%','babip'=>'BABIP','winpct'=>'Win %','gmovr500'=>'Gms Over .500');
		//$statArray=array('batters'=>'Batting','ab'=>'AB','h'=>'H','d'=>'2B','t'=>'3B','hr'=>'HR','rbi'=>'RBI','r'=>'R','sb'=>'SB','cs'=>'CS','bb'=>'BB','k'=>'K','sf'=>'SF','sh'=>'SH','ibb'=>'IBB','hp'=>'HBP','gdp'=>'GIDP','pa'=>'PA','outs'=>'Outs','ebh'=>'EBH','tb'=>'TB','tob'=>'TOB','tto'=>'TTO','pitches_seen'=>'Pitches Seen','pipa'=>'PS/PA','abhr'=>'AB/HR','pahr'=>'PA/HR','bbk'=>'BB/K','avg'=>'AVG','obp'=>'OBP','slg'=>'SLG','ops'=>'OPS','iso'=>'ISO','bbabip'=>'BABIP','wOBA'=>'wOBA','war'=>"WAR",'pwrspd'=>'PwrSpd','bsba'=>'SBA','sbPct'=>'SB%','rc'=>'RC','rc27'=>'RC/27','pitchers'=>'Pitching','w'=>'W','l'=>'L','s'=>'SV','ip'=>'IP','g'=>'G','gs'=>'GS','gf'=>'GF','cg'=>'CG','sho'=>'SHO','qs'=>'QS','pk'=>'K','pbb'=>'BB','ha'=>'HA','hra'=>'HR','pr'=>'R','er'=>'ER','hld'=>'HLD','svo'=>'SVO','bs'=>'BS','da'=>'2BA','ta'=>'3BA','bk'=>'BK','wp'=>'WP','hp'=>'HP','bf'=>'BF','gb'=>'GB','fb'=>'FB','ptto'=>'TTO','pi'=>'Pitches Thrown','era'=>'ERA','whip'=>'WHIP','pwar'=>'WAR','kper9'=>'K/9IP','bbper9'=>'BB/9IP','hper9'=>'H/9IP','rper9'=>'R/9IP','hrper9'=>'HR/9IP','kperbb'=>'K/BB','gbPct'=>'GB%','babip'=>'BABIP','winpct'=>'Win %','gmovr500'=>'Gms Over .500','fielders'=>'Fielding','fgs'=>'GS','po'=>'PO','a'=>'A','dp'=>'DP','tp'=>'TP','tc'=>'TC','e'=>'E','fip'=>'Inn','fpct'=>'Pct','rng'=>'Range','zr'=>'ZR','pb'=>'PB','sba'=>'RSTA','rto'=>'RTO','rtoPct'=>'RTO%');

		echo " <label for=\"" . $this->get_field_id( 'sl_stat' ) . "\">" . _e( 'Stat to Display:' ) . "</label>";
		echo " <select class=\"widefat\" id=\"" . $this->get_field_id( 'sl_stat' ) . "\" name=\"" . $this->get_field_name( 'sl_stat' ) . "\" type=\"text\" value=\"" . $sl_stat . "\" title=\"" . $sl_stat . "\">";
		foreach ($statArray as $key => $val)
		{
			if ($key=="batters")
			{
				echo "  <optgroup label=\"$val\">";
			}
			elseif (($key=="pitchers")||($key=="fielders"))
			{
				echo "  </optgroup>";
				echo "  <optgroup label=\"$val\">";
			}
			else
			{
				echo "  <option";
				echo selected( $instance['sl_stat'], $key);
				echo " value='$key'>";
				echo "$val</option>";
			}
		}
		echo "  </optgroup>";
		echo " </select>";
		/*
		// lastX
		echo " <label for=\"" . $this->get_field_id( 'sl_lastx' ) . "\">" . _e( 'Display Last X Draft Picks:' ) . "</label>";
		echo " <select class=\"widefat\" id=\"" . $this->get_field_id( 'sl_lastx' ) . "\" name=\"" . $this->get_field_name( 'sl_lastx' ) . "\" type=\"text\" value=\"" . $sl_lastx . "\">";
		foreach ($numberToDisplay as $key => $val)
		{
			echo "  <option";
			if ($val == $instance['sl_lastx']) {echo " selected='selected'";}
			echo ">$val</option>";
		}
		echo " </select>";

		// nextX
		echo " <label for=\"" . $this->get_field_id( 'sl_nextx' ) . "\">" . _e( 'Display Next X Draft Picks:' ) . "</label>";
		echo " <select class=\"widefat\" id=\"" . $this->get_field_id( 'sl_nextx' ) . "\" name=\"" . $this->get_field_name( 'sl_nextx' ) . "\" type=\"text\" value=\"" . $sl_nextx . "\">";
		foreach ($numberToDisplay as $key => $val)
		{
			echo "  <option";
			if ($val == $instance['sl_nextx']) {echo " selected='selected'";}
			echo ">$val</option>";
		}
		echo " </select>";
		 */

		echo "</p>";
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 */
	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
		$instance = array();
		$instance['title']        = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['sl_path']      = ( ! empty( $new_instance['sl_path'] ) ) ? strip_tags( $new_instance['sl_path'] ) : '';
		$instance['league_id']    = ( ! empty( $new_instance['league_id'] ) ) ? strip_tags( $new_instance['league_id'] ) : '';
		$instance['subleague_id'] = ( ! empty( $new_instance['subleague_id'] ) ) ? strip_tags( $new_instance['subleague_id'] ) : '';
		$instance['sl_topx']      = $new_instance['sl_topx'];
		$instance['sl_stat']      = $new_instance['sl_stat'];
		return $instance;
	}
	
	private function dispStatsLeaders( $instance) {
		$fpath=$instance['sl_path']."/config.txt";
		if (file_exists($fpath))
		{
			$f = fopen ($fpath, "r");
			$line = explode("|",fread($f,filesize($fpath)));
			$adminpath = trim($line[1]);
			fclose($f);
		}
		else {return "Unable to find StatsLab config file: $fpath";}

		$fpath=$adminpath."/dbopen.php";
		include($fpath);

		include($instance['sl_path']."/gen_functions.php");

		if ($db===null) {return "Unable to connect to database";}
	
		$text="";
		$league_id=$instance['league_id'];
		$subleague_id=$instance['subleague_id'];
		if ($subleague_id=="") {$subleague_id=0;}
		$stat=$instance['sl_stat'];
		$topX=$instance['sl_topx'];
	
		// Get Paths
		$query="SHOW TABLES LIKE 'ootp_sql_admin';";
		$result=mysql_query($query,$db);
		if (mysql_num_rows($result)) 
		{
			$query="SELECT setting,value FROM ootp_sql_admin WHERE module='admin' AND setting IN ('HTMLRoot','HTMLPath','ServerURL','StatsLabPath','priLgID')";
			$result=mysql_query($query,$db);
			if (mysql_num_rows($result)) 
			{
				while ($row=mysql_fetch_array($result))
				{
					$field=$row['setting'];
					$val=$row['value'];
					$val=stripslashes($val);
					switch ($field)
					{
					case 'HTMLRoot' : $htmlroot=$val; break;
					case 'HTMLPath' : $htmlpath=$val; break;
					case 'ServerURL': $serverURL=$val;break;
					case 'StatsLabPath': $StatsLabPath=$val;break;
					case 'priLgID'  : if ($lgid=="") {$lgid=$val;}break;
					}
				}
				$lgpath=$serverURL.$htmlpath;
				if (strtolower(substr($StatsLabPath,0,4))!="http") {$StatsLabPath=$serverURL.$StatsLabPath;}
			}
		}

		// Get team info
		$query="SELECT team_id,sub_league_id,name,nickname,abbr FROM teams WHERE league_id=$league_id AND allstar_team=0";
		$result=mysql_query($query,$db);
		if (mysql_num_rows($result)) 
		{
			while($row=mysql_fetch_array($result))
			{
				$tid=$row['team_id'];
				$teams[$tid]['city']=$row['name'];
				$teams[$tid]['nickname']=$row['nickname'];
				$teams[$tid]['name']=$row['name']." ".$row['nickname'];
				$teams[$tid]['abbr']=$row['abbr'];

				$slid=$row['sub_league_id'];
				$subleagues[$slid]['teams']=$subleagues[$slid]['teams'].",".$tid;
			}
			foreach ($subleagues as $slid => $val) {$subleagues[$slid]['teams']=trim($subleagues[$slid]['teams'],",");}
		}

		// Define Stat Context
		$split_id=1;
		$bool=">";
		$order_by="DESC";
		switch ($stat)
		{
	      		case 'abhr':
			case 'pahr':
				$bool="<";
				$order_by="ASC";
			case 'ab':
			case 'h':
	      		case 'd':
			case 't':
	      		case 'hr':
			case 'rbi':
	      		case 'r':
			case 'sb':
	      		case 'cs':
			case 'bb':
	      		case 'k':
			case 'sf':
	      		case 'sh':
			case 'ibb':
	      		case 'hp':
			case 'gdp':
	      		case 'pa':
			case 'outs':
	      		case 'ebh':
			case 'tb':
	      		case 'tob':
			case 'tto':
	      		case 'pitches_seen':
			case 'pipa':
	      		case 'bbk':
			case 'avg':
	      		case 'obp':
			case 'slg':
	      		case 'ops':
			case 'iso':
	      		case 'bbabip':
			case 'wOBA':
	      		case 'war':
			case 'pwrspd':
	      		case 'bsba':
			case 'sbPct':
	      		case 'rc':
			case 'rc27':
				$table="players_career_batting_stats";
				break;
			case 'fgs':
			case 'po':
	      		case 'a':
			case 'dp':
	      		case 'tp':
			case 'tc':
	      		case 'e':
			case 'fip':
	      		case 'fpct':
			case 'rng':
	      		case 'zr':
			case 'pb':
	      		case 'sba':
			case 'rto':
	      		case 'rtoPct':
				$table="players_career_fielding_stats";
				$split_id=0;
				break;
			case 'era':
			case 'whip':
			case 'bbper9':
			case 'hper9':
			case 'rper9':
			case 'hrper9':
			case 'babip':
				$bool="<";
				$order_by="ASC";
			default:
				$table="players_career_pitching_stats";
				break;
		}
		// Get Current Season
		$query="SELECT MAX(year) as year FROM $table WHERE league_id=$league_id AND split_id=$split_id";
		$result=mysql_query($query,$db);
		if (mysql_num_rows($result)) 
		{
			$row=mysql_fetch_array($result);
			$season=$row['year'];
		}
		else
		{
			return "No stats record in $table for league $league_id";
		}

		// Get Stat Leaders
		unset($query);
		$query.="SELECT first_name,last_name,organization_id,p.team_id,p.player_id,statVal FROM players as p RIGHT JOIN (";
		switch ($stat)
		{
			case 'avg':
			case 'obp':
			case 'slg':
			case 'ops':
			case 'pipa':
			case 'abhr':
			case 'pahr':
			case 'bbk':
			case 'iso':
			case 'bbabip':
			case 'wOBA':
			case 'sbPct':
			case 'era':
			case 'whip':
			case 'kper9':
			case 'bbper9':
			case 'hper9':
			case 'rper9':
			case 'hrper9':
			case 'kperbb':
			case 'gbPct':
			case 'babip':
			case 'winpct':
				$query.="SELECT x.* FROM team_record as t RIGHT JOIN (";
				break;
		}
		$query.="SELECT player_id,team_id,".stat_query($stat)." as statVal";
		switch ($stat)
		{
			case 'avg':
			case 'obp':
			case 'slg':
			case 'ops':
			case 'pipa':
			case 'abhr':
			case 'pahr':
			case 'bbk':
			case 'iso':
			case 'bbabip':
			case 'wOBA':
			case 'sbPct':
				$query.=",SUM(pa) as pt";
		      		break;
			case 'era':
			case 'whip':
			case 'kper9':
			case 'bbper9':
			case 'hper9':
			case 'rper9':
			case 'hrper9':
			case 'kperbb':
			case 'gbPct':
			case 'babip':
			case 'winpct':
				$query.=",(SUM(ip)+SUM(ipf)/3) as pt";
				break;
	  	}
		$query.=" FROM $table WHERE league_id=$league_id AND year=$season AND split_id=$split_id";
		if ($subleague_id>=0) {$query.=" AND team_id IN (".$subleagues[$subleague_id]['teams'].")";}
		$query.=" GROUP BY player_id";
		switch ($stat)
		{
			case 'avg':
			case 'obp':
			case 'slg':
			case 'ops':
			case 'pipa':
			case 'abhr':
			case 'pahr':
			case 'bbk':
			case 'iso':
			case 'bbabip':
			case 'wOBA':
			case 'sbPct':
				$query.=") as x ON t.team_id=x.team_id WHERE x.pt>=(3.1*t.g)";
		      		break;
			case 'era':
			case 'whip':
			case 'kper9':
			case 'bbper9':
			case 'hper9':
			case 'rper9':
			case 'hrper9':
			case 'kperbb':
			case 'gbPct':
			case 'babip':
			case 'winpct':
				$query.=") as x ON t.team_id=x.team_id WHERE x.pt>=(1.0*t.g)";
				break;
	  	}

		$query.=" ORDER BY statVal $order_by LIMIT $topX) as y ON p.player_id=y.player_id ORDER BY statVal $order_by,last_name,first_name";
		if ($_GET['showq']==1) {$text.=$query."</br>";}
		$result=mysql_query($query,$db);
		if (mysql_num_rows($result)) 
		{
			$rowcnt=mysql_num_rows($result);
			$text.="<table class='wdgT'>";
			$text.="<tr class='wdgH'>";
			$text.="<th class='wdgH_l'>Player</th>";
			$text.="<th>Tm</th>";
			$text.="<th>".stat_text($stat,2)."</th>";
			$text.="</tr>";

			$cnt=0;
			while($row=mysql_fetch_array($result))
			{
				$pid=$row['player_id'];
				$tid=$row['team_id'];
				$statVal=$row['statVal'];
				$fname=$row['first_name'];
				$fi=$fname[0];
				$lname=$row['last_name'];

				$cls='wdg'.($cnt%2+1);
				$text.="<tr class='$cls'>";
				$text.="<td class='".$cls."_l'>";
				$text.="<a href='$StatsLabPath/player.php?player_id=$pid'>$fi. $lname</a>";
				$text.="</td>";
				$text.="<td><a href='$lgpath/teams/team_$tid.html'>".$teams[$tid]['abbr']."</a></td>";
				$text.="<td>".stat_format($stat,$statVal)."</td>";
				$text.="</tr>";

				$cnt++;
				$lastVal=$statVal;
			}
			$text.="</table>";
		}		

		return $text;
		mysql_close($db);
	}	
}

// Register and load the widget
function statslab_ootp_load_widget() {
    register_widget( 'StatsLab_OOTP_Widget' );
}

add_action( 'widgets_init', 'statslab_ootp_load_widget' );


?>
